@@ -200,13 +200,18 @@ class _inject:
 
     def _update_signature(self, f):
         sig = inspect.signature(f)
-        parameters = list(sig.parameters.items())
+        parameters = collections.OrderedDict(
+            [
+                (n, p) for n, p in list(sig.parameters.items())
+                if n != self.attname
+
+            ]
+        )
         f.__annotations__ = collections.OrderedDict(
-            [(n, p) for n, p in parameters if n != self.attname]
-        )
-        f.__signature__ = sig.replace(
-            parameters=list(f.__annotations__.values())
+            [(n, p.annotation)
+            for n, p in list(parameters.items()) if p.annotation]
         )
+        f.__signature__ = sig.replace(parameters=list(parameters.values()))
 
 
 @contextlib.asynccontextmanager
